// <file>
//     <copyright see="prj:///doc/copyright.txt"/>
//     <license see="prj:///doc/license.txt"/>
//     <owner name="Andrea Paatz" email="andrea@icsharpcode.net"/>
//     <version>$Revision: 4482 $</version>
// </file>

namespace ICSharpCode.OldNRefactory.Ast
{
	public interface INullable
	{
		bool IsNull {
			get;
		}
	}
}
